# cli programs should be available on servers and desktop
{ lib, pkgs, ... }:

{
  programs = {
    mosh.enable = true;
    neovim = {
      enable = true;
      viAlias = true;
      vimAlias = true;
    };
    ssh.startAgent = true;
    starship = {
      enable = true;
      settings = with builtins; fromTOML (readFile ../configs/starship.toml);
    };
    zsh = {
      enable = true;
      autosuggestions.enable = true;
      shellAliases = {
        ls = "lsd --hyperlink=auto";
        icat = "kitty +kitten icat";
        nixedit = "codium /etc/nixos";
        nixupdate = "sudo nix-channel --update && sudo nixos-rebuild switch";
        nixclean = "sudo nix-env --delete-generations old --profile /nix/var/nix/profiles/system && sudo /nix/var/nix/profiles/system/bin/switch-to-configuration switch && sudo nix-store --gc";
      };
      shellInit = "cd ~/Developpements;";
      ohMyZsh = {
        enable = true;
        plugins = [ "git" "ssh-agent" ];
        theme = "robbyrussell";
      };
    };
  };

  # List packages installed in system profile. To search, run:
  # $ nix search wget
  environment.systemPackages = with pkgs; [
    ansible
    bat
    bitwarden-cli
    coreutils
    curl
    dnsutils
    emacs-nox
    findutils
    gnugrep
    gnumake
    gnupg
    imagemagick
    jq
    git
    glances
    htop
    lsd
    mc
    micro
    mosh
    neofetch
    pandoc
    pass
    pciutils
    pinentry
    starship
    tmux
    tree
    unzip
    usbutils
    wget
    whois
    wirelesstools
    zola
    zsh-autosuggestions
  ];
}
